#[repr(u8)]pub enum Asp {
NONE = 0,
ECC_ONLY = 1,
AS_NPPE = 2,
AS_PPE = 3,
}Variants
NONE = 0
No Safety features selected.
ECC_ONLY = 1
Only “ECC protection for external memory” feature is selected.
AS_NPPE = 2
All the Automotive Safety features are selected without the “Parity Port Enable for external interface” feature.
AS_PPE = 3
All the Automotive Safety features are selected with the “Parity Port Enable for external interface” feature.
Implementations