#[repr(u8)]pub enum Tsctrlssr {
DIG_DISABLE = 0,
DIG_ENABLE = 1,
}Variants
DIG_DISABLE = 0
Timestamp Digital Rollover Control is disabled and Binary Rollover Control is enabled
DIG_ENABLE = 1
Timestamp Digital Rollover Control is enabled and Binary Rollover Control is disabled
Implementations